@@ -12,9 +12,9 @@
 (**************************************************************************)
 
 open! ExtLib
-open Common
-open Debian
-open Algo
+open Dose_common
+open Dose_debian
+open Dose_algo
 
 #define __label __FILE__
 let label =  __label ;;
@@ -256,7 +256,7 @@ let unique ll =
 ;;
 
 let optimal_subset ?(global_constraints=[]) ?(available=(fun _ -> true)) pkg univ closure =
-  let dummy = { Algo.Depsolver.dummy_request with
+  let dummy = { Depsolver.dummy_request with
                 Cudf.depends =
                   List.map (fun (_,pkglist) ->
                       List.map (fun uid ->
@@ -366,9 +366,9 @@ let compute_dependency_sets_opt ?(global_constraints=[]) ?(partition=true) ?(ava
     | None -> begin
         let r = optimal_subset ~global_constraints ~available (CudfAdd.inttopkg univ pid) univ (IntSet.elements dcs) in
         let is = match r with
-          |Algo.Depsolver.Error s -> fatal "%s" s;
-          |Algo.Depsolver.Unsat _ -> fatal "this must not happen";
-          |Algo.Depsolver.Sat (_,soluniv) ->
+          |Depsolver.Error s -> fatal "%s" s;
+          |Depsolver.Unsat _ -> fatal "this must not happen";
+          |Depsolver.Sat (_,soluniv) ->
             Cudf.fold_packages (fun acc pkg ->
                 IntSet.add (CudfAdd.pkgtoint univ pkg) acc
               ) IntSet.empty soluniv
@@ -383,8 +383,8 @@ let compute_dependency_sets_opt ?(global_constraints=[]) ?(partition=true) ?(ava
    * have to be cached *)
   let r = optimal_subset ~global_constraints ~available srcpkg univ closure in
   begin match r with
-    |Algo.Depsolver.Error s -> fatal "%s" s;
-    |Algo.Depsolver.Unsat diagnosis -> begin
+    |Depsolver.Error s -> fatal "%s" s;
+    |Depsolver.Unsat diagnosis -> begin
         if Util.Debug.is_enabled "BootstrapCommon" then begin match diagnosis with
           | None -> ()
           | Some diagnosis -> Diagnostic.fprintf ~explain:true ~failure:true Format.err_formatter diagnosis
@@ -393,7 +393,7 @@ let compute_dependency_sets_opt ?(global_constraints=[]) ?(partition=true) ?(ava
           (string_of_package srcpkg);
         IntSet.empty, []
       end
-    |Algo.Depsolver.Sat (_,soluniv) -> begin
+    |Depsolver.Sat (_,soluniv) -> begin
         (* remove source package from installation set *)
         let iss = Cudf.fold_packages (fun acc pkg ->
             IntSet.add (CudfAdd.pkgtoint univ pkg) acc
@@ -669,7 +669,7 @@ let parse_debian_pkgstring universe native_arch pkgstring =
         |(_,None) ->
           raise (Format822.ParseError ([],s,"you must specify a version" ))
         |_ -> raise (Format822.ParseError ([],s,""))
-      ) (Pef.Packages.parse_vpkglist ("pkgstring", (_loc,s)))
+      ) (Dose_pef.Packages.parse_vpkglist ("pkgstring", (_loc,s)))
   in
   List.fold_left (fun acc (n,a,v) ->
       let cudfname = match a with
