@@ -12,9 +12,9 @@
 (**************************************************************************)
 
 open! ExtLib
-open Common
-open Debian
-open Algo
+open Dose_common
+open Dose_debian
+open Dose_algo
 
 #define __label __FILE__
 let label =  __label ;;
@@ -121,10 +121,44 @@ let graph_helper ?(num_cores=1) available bin2src univ partitionofsrc sl =
              * https://github.com/rdicosmo/parmap/issues/46
              *)
             let rec splitjob maxsplits todo =
+                    let parmap ~ncores ?(csize = 1) f l =
+                      if ncores <= 1 then List.map f l
+                      else
+                        (*
+                        let input = ref l in
+                        let demux () = match !input with
+                          | [] -> raise Parany.End_of_input
+                          | x :: xs -> (input := xs; x) in
+                        let output = ref [] in
+                        let mux x =
+                          output := x :: !output in
+                           *)
+                        let inarray = Array.of_list l in
+                        let outarray = Array.make (List.length l) (0,[]) in
+                        let counter = ref 0 in
+                        let demux () =
+                          if !counter = List.length l then
+                            raise Parany.End_of_input
+                          else
+                            let res = (!counter, inarray.(!counter)) in
+                            incr counter;
+                            res
+                        in
+                        let mux (i,x) = outarray.(i) <- x in
+                        let fwrapper (i,x) = (i,f x) in
+                        (* for safety *)
+                        Parany.set_copy_on_work ();
+                        Parany.set_copy_on_mux ();
+                        (* parallel work *)
+                        Parany.run ~verbose:false ~csize ~nprocs:ncores ~demux ~work:fwrapper ~mux;
+                        (*!output*)
+                        Array.to_list outarray
+                    in parmap ~ncores:num_cores worker todo
+(*
               try
                 Parmap.parmap ~ncores:num_cores worker (Parmap.L todo)
               with
-              | Failure "input_value_from_block: bad object" -> begin
+              | Failure "input_value_from_block: bad object" |Out_of_memory -> begin
                   if maxsplits <= 0 then fatal "exceeded maximum split depth";
                   warning "parmap raised out of memory exception with list length %d, splitting job..." (List.length todo);
                   let l1, l2 = List.split_nth ((List.length todo)/2) todo in
@@ -132,6 +166,7 @@ let graph_helper ?(num_cores=1) available bin2src univ partitionofsrc sl =
                   let res2 = splitjob (maxsplits-1) l2 in
                   List.append res1 res2
                 end
+    *)
             in
             let maxsplits = 4 in
             splitjob maxsplits todo
