@@ -12,9 +12,9 @@
 (**************************************************************************)
 
 open! ExtLib
-open Common
-open Debian
-open DoseparseNoRpm
+open Dose_common
+open Dose_debian
+open Dose_doseparse
 
 #define __label __FILE__
 let label =  __label ;;
@@ -85,10 +85,10 @@ let main () =
   StdDebug.enable_bars (OptParse.Opt.get Options.progress) ["build_graph"; "Strongdeps_int.main"];
 
   let options = Options.set_deb_options () in
-  let hostarch = match options.Debian.Debcudf.host with None -> "" | Some s -> s in
-  let buildarch = Option.get options.Debian.Debcudf.native in
-  let foreignarchs = options.Debian.Debcudf.foreign in
-  let noindep = options.Debian.Debcudf.drop_bd_indep in
+  let hostarch = match options.Debcudf.host with None -> "" | Some s -> s in
+  let buildarch = Option.get options.Debcudf.native in
+  let foreignarchs = options.Debcudf.foreign in
+  let noindep = options.Debcudf.drop_bd_indep in
   let custom_is_files = OptParse.Opt.get Options.custom_is_files in
   let allowsrcmismatch = OptParse.Opt.get Options.allowsrcmismatch in
   let strongtype = OptParse.Opt.get Options.strongtype in
@@ -108,12 +108,12 @@ let main () =
 
   let (binlist, (fgsrclist,bgsrclist), _) = BootstrapCommon.parse_packages ~noindep Options.parse_cmdline buildarch hostarch foreignarchs posargs in
 
-  let tables = Debian.Debcudf.init_tables ~options (fgsrclist@bgsrclist@binlist) in
-  let global_constraints = Debian.Debcudf.get_essential ~options tables in
-  let fgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
-  let bgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
+  let tables = Debcudf.init_tables ~options (fgsrclist@bgsrclist@binlist) in
+  let global_constraints = Debcudf.get_essential ~options tables in
+  let fgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
+  let bgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
   (* create a universe from foreground and background packages *)
-  let pkglist = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) binlist in
+  let pkglist = List.map (Debcudf.tocudf ?inst:None ~options tables) binlist in
   let universe = Cudf.load_universe (BootstrapCommon.unique [pkglist;fgsl;bgsl]) in
 
   (* read package list for available packages *)
