@@ -12,9 +12,9 @@
 (**************************************************************************)
 
 open! ExtLib
-open Common
-open Debian
-open DoseparseNoRpm
+open Dose_common
+open Dose_debian
+open Dose_doseparse
 
 #define __label __FILE__
 let label =  __label ;;
@@ -66,18 +66,18 @@ let main () =
   Util.Warning.disable "Sources";
 
   let options = Options.set_deb_options () in
-  let buildarch = Option.get options.Debian.Debcudf.native in
-  let hostarch = match options.Debian.Debcudf.host with None -> "" | Some s -> s in
-  let foreignarchs = options.Debian.Debcudf.foreign in
+  let buildarch = Option.get options.Debcudf.native in
+  let hostarch = match options.Debcudf.host with None -> "" | Some s -> s in
+  let foreignarchs = options.Debcudf.foreign in
   let allowsrcmismatch = OptParse.Opt.get Options.allowsrcmismatch in
   let ignoresrclessbin = OptParse.Opt.get Options.ignoresrclessbin in
 
   let binlist, (fgsrclist,bgsrclist), _ = BootstrapCommon.parse_packages Options.parse_cmdline buildarch hostarch foreignarchs posargs in
 
-  let tables = Debian.Debcudf.init_tables (fgsrclist@bgsrclist@binlist) in
-  let fgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
-  let bgsl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
-  let bl = List.map (Debian.Debcudf.tocudf ?inst:None ~options tables) binlist in
+  let tables = Debcudf.init_tables (fgsrclist@bgsrclist@binlist) in
+  let fgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) fgsrclist in
+  let bgsl = List.map (Debcudf.tocudf ?inst:None ~options tables) bgsrclist in
+  let bl = List.map (Debcudf.tocudf ?inst:None ~options tables) binlist in
 
   (* create a hashtable mapping cudf package name,version,arch tuples to
    * Packages.package format822 stanzas *)
