@@ -14,6 +14,9 @@ ALLOWSRCMISMATCH=
 IGNORESRCLESSBIN=
 SAPSB=
 ONLINE=
+OPTGRAPH=
+DROPBDINDEP=
+VERBOSE=
 
 usage() {
 	echo "usage: $PROGNAME [OPTIONS] [buildarch hostarch buildpackages sources]" >&2
