@@ -10,8 +10,8 @@ from util import read_json_file
 from functools import reduce
 
 
-def partition(l, p):
-    return reduce(lambda x, y: x[not p(y)].append(y) or x, l, ([], []))
+def partition(L, p):
+    return reduce(lambda x, y: x[not p(y)].append(y) or x, L, ([], []))
 
 
 # string of package
@@ -27,19 +27,23 @@ def sob(binpkg):
 
 def sos(srcpkg):
     name, ver = srcpkg
-    return '<a href="/source/%s_%s.html" class="pkg"' % (
-        name,
-        ver,
-    ) + ' title="src:%s&nbsp;(=&nbsp;%s)">src:%s</a>' % (name, ver, name)
+    return (
+        '<a href="/source/%s_%s.html" class="pkg"'
+        % (
+            name,
+            ver,
+        )
+        + ' title="src:%s&nbsp;(=&nbsp;%s)">src:%s</a>' % (name, ver, name)
+    )
 
 
 # string of list
-def sobl(l):
-    return ", ".join([sob(pkg) for pkg in l])
+def sobl(L):
+    return ", ".join([sob(pkg) for pkg in L])
 
 
-def sosl(l):
-    return ", ".join([sos(pkg) for pkg in l])
+def sosl(L):
+    return ", ".join([sos(pkg) for pkg in L])
 
 
 # string of vector
@@ -48,10 +52,14 @@ def sov(vertex):
     if t == "SrcPkg":
         name, ver = data
         fullname = "src:%s&nbsp;(=&nbsp;%s)" % (name, ver)
-        return '<a href="/source/%s_%s.html" class="pkg"' % (
-            name,
-            ver,
-        ) + ' title="%s">src:%s</a>' % (fullname, name)
+        return (
+            '<a href="/source/%s_%s.html" class="pkg"'
+            % (
+                name,
+                ver,
+            )
+            + ' title="%s">src:%s</a>' % (fullname, name)
+        )
     elif t == "InstSet":
         (name, arch, ver), instset = data
         instset = ", ".join(
@@ -228,9 +236,8 @@ third column by the amount of packages in the fourth column</p>""",
             "title": "Only Weak Build Dependencies Missing",
             "descr": '<p>Source packages that only lack "weak" '
             + "build dependencies as classified as such by "
-            + '<a href="https://gitlab.mister-muffin.de/'
-            + "debian-bootstrap/botch"
-            + '/blob/master/droppable/weak-build-dependencies.list"'
+            + '<a href="https://salsa.debian.org/debian-bootstrap-team/'
+            + 'botch/-/raw/master/droppable/weak-build-dependencies.list"'
             + ">this list</a>.</p>",
             "heads": ["Amount", "Source Package", "Weak Build Dependencies"],
             "printer": lambda src, deps: ("%d" % (len(deps)), sos(src), sobl(deps)),
